import aws4 from 'aws4'
import mqtt from 'mqtt'

function signRequest ({ endpoint, region, accessKeyId, secretAccessKey }) {
  return aws4.sign({
    host: endpoint,
    path: '/mqtt',
    service: 'iotdevicegateway',
    region,
    signQuery: true
  }, {
    accessKeyId,
    secretAccessKey
  })
}

export function getClient ({ endpoint, region, accessKeyId, secretAccessKey, sessionToken }) {
  // NOTE: IoT does not expect X-Amz-Security-Token to be included in the signature, but it must be added in the path
  const { path } = signRequest({ endpoint, region, accessKeyId, secretAccessKey })
  const url = `wss://${endpoint}${path}&X-Amz-Security-Token=${encodeURIComponent(sessionToken)}`
  const client = mqtt.connect(url)

  return client
}
